@@ -84,5 +84,5 @@ def home():
 
 
 if __name__ == '__main__':
-    app.run(debug=False, host="localhost", port=8442) 
+    app.run(debug=False, host="0.0.0.0", port=8442) 
 
